#ifndef NT2_INCLUDE_FUNCTIONS_SCALAR_GAMCDF_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_SCALAR_GAMCDF_HPP_INCLUDED

#include <nt2/statistics/include/functions/scalar/gamcdf.hpp>

#endif
